package com.bffmedia.hour16app;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;

import org.json.JSONException;


import android.app.ActionBar;
import android.app.ActionBar.Tab;
import android.app.Activity;
import android.app.FragmentTransaction;
import android.content.ContentValues;
import android.database.Cursor;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ProgressBar;
import android.widget.Toast;

public class MainActivity extends Activity {
	ProgressBar mProgressBar;
	Tab mPhotosTab;
	Tab mFavoritesTab;
	Boolean showList = true;
	
	private ArrayList<FlickrPhoto> mPhotos = new ArrayList<FlickrPhoto>();

	public final static String API_KEY ="PUT_YOUR_API_KEY_HERE";
	public final static String NUM_PHOTOS ="12";
	private static final String TAG = MainActivity.class.getName();

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		ActionBar actionBar = getActionBar();	
		actionBar.setNavigationMode(ActionBar.NAVIGATION_MODE_TABS);
		mPhotosTab= actionBar.newTab().setText("Photos").setTabListener(new NavTabListener());
		actionBar.addTab(mPhotosTab);
		mFavoritesTab= actionBar.newTab().setText("Favorites").setTabListener(new NavTabListener());
		actionBar.addTab(mFavoritesTab);
		mProgressBar = (ProgressBar) findViewById(R.id.progressBar1);
		if (isOnline()){
			LoadPhotos task = new LoadPhotos();
			task.execute();
		}else{
			mProgressBar.setVisibility(View.GONE);
		}
	
		
	}

	public ArrayList<FlickrPhoto> getPhotos() {
		return mPhotos;
	}

	public void setPhotos(ArrayList<FlickrPhoto> mPhotos) {
		this.mPhotos = mPhotos;
	}
	
	public boolean isOnline() {
	    ConnectivityManager connectivityManager = (ConnectivityManager) 
	            getSystemService(this.CONNECTIVITY_SERVICE);
	    NetworkInfo networkInfo = connectivityManager.getActiveNetworkInfo();
	    return (networkInfo != null && networkInfo.isConnected());
	}  

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.activity_main, menu);
		return true;
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
		case R.id.menu_show_as_list:
			showList=true;
			if (getActionBar().getSelectedTab() == mPhotosTab){
				showList(true);
			}else{
				showList(false);
			}
			return true;
		case R.id.menu_show_as_grid:
			showList = false;
			if (getActionBar().getSelectedTab() == mPhotosTab){
				showGrid(true);
			}else{
				showGrid(false);
			}

			return true;
		case R.id.menu_clear:
			int result = getContentResolver().delete( FlickrPhotoProvider.CONTENT_URI,  "isFavorite='0'", null );
	      	Log.d ("MainActivity", "result " + result);
	      	
	      	if (getActionBar().getSelectedTab()==(mPhotosTab)){
				if (showList){
					showList(true);
				}else{
					showGrid(true);
				}
			}else{
				if (showList){
					showList(false);
				}else{
					showGrid(false);
				}
			}
			
			
			return true;
		
		default:
			return super.onOptionsItemSelected(item);
		}	
	}
	
	
	public void showList(Boolean all){
		Bundle args = new Bundle();  
		if (all){
			args.putBoolean("ALL", true);
		}else{
			args.putBoolean("ALL", false);
		}
		PhotoListFragment photoListFragment = new PhotoListFragment();
		photoListFragment.setArguments(args);
		FragmentTransaction ft = getFragmentManager().beginTransaction();
		ft.replace(R.id.layout_container, photoListFragment);
		ft.setTransition(FragmentTransaction.TRANSIT_FRAGMENT_FADE);
		ft.commit();
	}
	public void showGrid(Boolean all){
		Bundle args = new Bundle();  
		if (all){
			args.putBoolean("ALL", true);
		}else{
			args.putBoolean("ALL", false);
		}
		PhotoGridFragment photoGridFragment = new PhotoGridFragment();
		photoGridFragment.setArguments(args);
		FragmentTransaction ft = getFragmentManager().beginTransaction();
		ft.replace(R.id.layout_container, photoGridFragment);
		ft.setTransition(FragmentTransaction.TRANSIT_FRAGMENT_FADE);
		ft.commit();
	}
	
	private class NavTabListener implements ActionBar.TabListener {
		public NavTabListener() {
		}
		@Override
		public void onTabReselected(Tab tab, FragmentTransaction ft) {
		}
		@Override
		public void onTabSelected(Tab tab, FragmentTransaction ft) {
			if (tab.equals(mPhotosTab)){
				if (showList){
					showList(true);
				}else{
					showGrid(true);
				}
			}else{
				if (showList){
					showList(false);
				}else{
					showGrid(false);
				}
			}
		}
		@Override
		public void onTabUnselected(Tab tab, FragmentTransaction ft) {
		}
	}
	
	private class LoadPhotos extends AsyncTask<String , String , Long > {
		

		@Override
		protected void onPreExecute() {
		}

		@Override
		protected void onPostExecute(Long result) {
			if (result==0){
				showList(true);
			}else{
				Toast.makeText(MainActivity.this.getApplicationContext(), "Something went wrong", Toast.LENGTH_SHORT).show();
			}
			mProgressBar.setVisibility(View.GONE);
		}

		@Override
		protected Long doInBackground(String... params) {
			HttpURLConnection connection = null;
			FlickrPhotoDbAdapter photoDbAdapter = new FlickrPhotoDbAdapter(MainActivity.this);
			photoDbAdapter.open();
			try {
				URL dataUrl = new URL("http://api.flickr.com/services/rest/?method=flickr.photos.getRecent&api_key="+ API_KEY+ "&per_page=" + NUM_PHOTOS +"&format=json&nojsoncallback=1");
				connection = (HttpURLConnection) dataUrl.openConnection();
				connection.connect();
				int status = connection.getResponseCode();
				Log.d("connection", "status " + status);
				if (status ==200){
				  InputStream is = connection.getInputStream();
				  BufferedReader reader = new BufferedReader(new InputStreamReader(is));
				  String responseString;
				  StringBuilder sb = new StringBuilder();
				  while ((responseString = reader.readLine()) != null) {
					  sb = sb.append(responseString);
				  }
				  String photoData = sb.toString();
				  mPhotos = FlickrPhoto.makePhotoList(photoData);
				  for (FlickrPhoto currentPhoto : mPhotos) {
					  ContentValues newValues = new ContentValues();
						if (currentPhoto.id!=null)
							newValues.put("flickr_id", currentPhoto.id);	
						if (currentPhoto.owner!=null)
							newValues.put("owner", currentPhoto.owner);	
						if (currentPhoto.secret!=null)
							newValues.put("secret", currentPhoto.secret);	
						if (currentPhoto.server!=null)
							newValues.put("server", currentPhoto.server);	
						if (currentPhoto.farm!=null)
							newValues.put("farm", currentPhoto.farm);	
						if (currentPhoto.title!=null)
							newValues.put("title", currentPhoto.title);	
						if (currentPhoto.isPublic!=null)
							newValues.put("isPublic", currentPhoto.isPublic);	
						if (currentPhoto.isFriend!=null)
							newValues.put("isFriend", currentPhoto.isFriend);	
						if (currentPhoto.isFamily!=null)
							newValues.put("isFamily", currentPhoto.isFamily);	
						if (currentPhoto.isFavorite!=null)
							newValues.put("isFavorite", currentPhoto.isFavorite);		
						
				
						Cursor photoCursor = managedQuery(Uri.withAppendedPath(FlickrPhotoProvider.CONTENT_URI ,currentPhoto.id), null, null, null, null);
						if (photoCursor.moveToFirst()){
							 FlickrPhoto existingPhoto = FlickrPhotoDbAdapter.getPhotoFromCursor(photoCursor);
							 photoDbAdapter.updatePhoto(existingPhoto.id, currentPhoto);
							 Log.d(TAG,"Updated " + existingPhoto.id);
							 photoCursor.close();
						}else{
							Uri newUri = getContentResolver().insert(
									FlickrPhotoProvider.CONTENT_URI, 
									newValues);   

						}
	
					} 
				  
				  Log.d("connection", photoData);
				  return (0l);
				}else{
					return (1l);
				}
			} catch (MalformedURLException e) {
				e.printStackTrace();
				return (1l);
			} 
			catch (IOException e) {
				System.out.println("IOException");
				e.printStackTrace();
				return (1l);
			} catch (NullPointerException e) {
				e.printStackTrace();
				return (1l);
			} catch (JSONException e) {
				e.printStackTrace();
				return (1l);
			} finally {
				connection.disconnect();
				photoDbAdapter.close();
			}
		}
	}

}
