package com.bffmedia.hour20;

import java.io.*;
import java.text.SimpleDateFormat;
import java.util.Collections;
import java.util.Comparator;
import java.util.Date;
import java.util.List;

import android.app.Activity;
import android.content.Intent;
import android.hardware.Camera;
import android.hardware.Camera.Size;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.view.Display;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.RelativeLayout;
import android.widget.Toast;

public class CustomCameraActivity extends Activity {
	private Camera mCamera;
	private CameraPreview mPreview;
	private Camera.PictureCallback mPicture;
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_custom_camera);
		try{
			//open the Camera and display the Preview in the FrameLayout preview
			mCamera = Camera.open(); 
			mPreview = new CameraPreview(this, mCamera);
			FrameLayout preview = (FrameLayout) findViewById(R.id.previewFrameLayout);
			preview.addView(mPreview);
			
			//Get the possible sizes for preview
			Camera.Parameters currentParameters = mCamera.getParameters();
			List<Camera.Size> sizes =   currentParameters.getSupportedPreviewSizes();
			
			//Sort size by ascending Height
			Collections.sort(sizes, new OrderByHeight());
			
			//Set bestSize to the smallest
			Camera.Size bestSize = sizes.get(0);
			
			//Get size of the display
			Display display = getWindowManager().getDefaultDisplay(); 
			int width = display.getWidth();  
			int height = display.getHeight();  
			
			// Test each preview size and make the best size the largest one whose height appears in the display
			for (Camera.Size size: sizes){
				System.out.println("size is " + size.width+"," +size.height);
				if (size.height< height && size.height > bestSize.height && size.width < width && size.width > bestSize.width){
					bestSize = size;
				}
			}
			
			// Set the layout size to the best size, center the layout, make it to the left of the takePicture Button
			RelativeLayout.LayoutParams layoutParams = new RelativeLayout.LayoutParams(bestSize.width, bestSize.height);
			layoutParams.addRule(RelativeLayout.CENTER_VERTICAL);
			layoutParams.addRule(RelativeLayout.LEFT_OF, R.id.takePicture);
			preview.setLayoutParams(layoutParams);
			
			
			//Implement the takePictureButton
			Button takePictureButton = (Button) findViewById(R.id.takePicture);
			takePictureButton.setOnClickListener(new OnClickListener() {
				public void onClick(View v) {
					mCamera.takePicture(null, null, mPicture);
				}
			});


		}   catch (Exception e){
		}

		mPicture= new Camera.PictureCallback() {
			@Override
			public void onPictureTaken(byte[] data, Camera camera) {	    	
				File mediaStorageDir = new File(Environment.getExternalStoragePublicDirectory(
						Environment.DIRECTORY_PICTURES), "Hour20");
				if (! mediaStorageDir.exists()){
					mediaStorageDir.mkdirs();
				}
				String timeStamp = new SimpleDateFormat("yyyyMMdd_HHmmss").format(new Date());
				String displayFolder = "Pictures" + File.separator +"Hour20" + File.separator +"IMG_"+ timeStamp + ".jpg";
				File photoFile = new File(mediaStorageDir.getPath() + File.separator +"IMG_"+ timeStamp + ".jpg");
				Uri photoFileUri=Uri.fromFile(photoFile);
				try {
					FileOutputStream fos = new FileOutputStream(photoFile);
					fos.write(data);
					fos.close();
					Toast.makeText(CustomCameraActivity.this, "Image saved to:\n" +
							displayFolder, Toast.LENGTH_LONG).show();	
					Intent mediaScanIntent = new Intent(Intent.ACTION_MEDIA_SCANNER_SCAN_FILE);
					mediaScanIntent.setData(photoFileUri);
					CustomCameraActivity.this.sendBroadcast(mediaScanIntent);
					mCamera.startPreview();
				} catch (FileNotFoundException e) {
					Toast.makeText(CustomCameraActivity.this, "Something went wrong", Toast.LENGTH_LONG).show();
				} catch (IOException e) {
					Toast.makeText(CustomCameraActivity.this, "Something went wrong", Toast.LENGTH_LONG).show();

				}
			}
		};


	}
	@Override
	public void onPause(){
		super.onPause();
		mCamera.stopPreview();
		mCamera.release();
	}

	public static class OrderByHeight implements Comparator<Camera.Size> {
		@Override
		public int compare(Size size1, Size size2) {
			if (size1.height < size2.height ) return -1;
			if (size1.height == size2.height ) return 0;
			if (size1.height > size2.height ) return 1;
			return 0;
		}

	}




}
