package com.bffmedia.hour20;

import java.io.*;
import java.text.SimpleDateFormat;
import java.util.Collections;
import java.util.Date;
import java.util.List;

import com.bffmedia.hour20.CustomCameraActivity.OrderByHeight;

import android.app.Activity;
import android.content.Intent;
import android.hardware.Camera;
import android.media.CamcorderProfile;
import android.media.MediaRecorder;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.view.Display;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.RelativeLayout;
import android.widget.Toast;

public class CustomVideoActivity extends Activity {
	private Camera mCamera;
	MediaRecorder mMediaRecorder;
	private CameraPreview mPreview;
	private boolean mRecording = false;
	private File mVideoFile;
	private Uri mVideoFileUri;
	private String mDisplayFolder;
	private Button mVideoButton;
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_custom_video);
		try{
			mCamera = Camera.open(); 
			mPreview = new CameraPreview(this, mCamera);
			FrameLayout preview = (FrameLayout) findViewById(R.id.previewFrameLayout);
			preview.addView(mPreview);
			Camera.Parameters currentParameters = mCamera.getParameters();
			List<Camera.Size> sizes =   currentParameters.getSupportedPreviewSizes();
			Collections.sort(sizes, new CustomCameraActivity.OrderByHeight());
			Camera.Size bestSize = sizes.get(0);
			Display display = getWindowManager().getDefaultDisplay(); 
			int width = display.getWidth();  
			int height = display.getHeight();  
			System.out.println("height " + height);
			System.out.println("width " + width);
			for (Camera.Size size: sizes){
				System.out.println("size is " + size.width+"," +size.height);
				if (size.height< height && size.height > bestSize.height && size.width < width && size.width > bestSize.width){
					System.out.println("best size " + size.width+"," +size.height);
					bestSize = size;
				}
			}
			RelativeLayout.LayoutParams layoutParams = new RelativeLayout.LayoutParams(bestSize.width, bestSize.height);
			layoutParams.addRule(RelativeLayout.CENTER_VERTICAL);
			layoutParams.addRule(RelativeLayout.LEFT_OF, R.id.shootVideo);
			preview.setLayoutParams(layoutParams);
			
			mVideoButton = (Button) findViewById(R.id.shootVideo);
			mVideoButton.setOnClickListener(new OnClickListener() {
				public void onClick(View v) {
					if (mRecording){
						mRecording = false;
						mMediaRecorder.stop(); 
						mMediaRecorder.reset();   
						mMediaRecorder.release(); 
						mMediaRecorder = null;
						mCamera.lock();         
						mVideoButton.setText("Start Recording");
			            Toast.makeText(CustomVideoActivity.this, "Video saved to:\n" +
			            		mDisplayFolder, Toast.LENGTH_LONG).show();

					}else{
						mRecording =true;
						mMediaRecorder = new MediaRecorder();
						mCamera.unlock();
						mMediaRecorder.setCamera(mCamera);
						mMediaRecorder.setAudioSource(MediaRecorder.AudioSource.DEFAULT);
						mMediaRecorder.setVideoSource(MediaRecorder.VideoSource.CAMERA);
						mMediaRecorder.setProfile(CamcorderProfile.get(CamcorderProfile.QUALITY_HIGH));
						File mediaStorageDir = new File(Environment.getExternalStoragePublicDirectory(
								Environment.DIRECTORY_PICTURES), "Hour20");
						if (! mediaStorageDir.exists()){
							mediaStorageDir.mkdirs();
						}
						String timeStamp = new SimpleDateFormat("yyyyMMdd_HHmmss").format(new Date());
						mDisplayFolder = "Pictures" + File.separator +"Hour20" + File.separator +"VID_"+ timeStamp + ".mp4";
						mVideoFile = new File(mediaStorageDir.getPath() + File.separator +"VID_"+ timeStamp + ".mp4");
						mVideoFileUri=Uri.fromFile(mVideoFile);					    
						mMediaRecorder.setOutputFile(mVideoFile.toString());
						mMediaRecorder.setPreviewDisplay(mPreview.getHolder().getSurface());
						try {
							mMediaRecorder.prepare();
							mMediaRecorder.start();
							mVideoButton.setText("Stop Recording");
							   Intent mediaScanIntent = new Intent(Intent.ACTION_MEDIA_SCANNER_SCAN_FILE);
				                mediaScanIntent.setData(mVideoFileUri);
				                CustomVideoActivity.this.sendBroadcast(mediaScanIntent);

						} catch (IllegalStateException e) {

						} catch (IOException e) {

						}

					}
				}
			});


		}   catch (Exception e){
		}



	}
	@Override
	public void onPause(){
		super.onPause();
		if (mCamera!=null){
			mCamera.stopPreview();
			mCamera.release();
			mCamera=null;	
		}
		
		if (mMediaRecorder!=null){
			mMediaRecorder.stop(); 
			mMediaRecorder.reset();   
			mMediaRecorder.release(); 
			mMediaRecorder = null;
		}
		
	}



}
