package com.bffmedia.hour20;

import java.io.File;
import java.text.SimpleDateFormat;
import java.util.Date;



import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.app.Activity;
import android.content.Intent;
import android.util.Log;
import android.view.Menu;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.Toast;

public class MainActivity extends Activity {
	private static final int CAPTURE_IMAGE_REQUEST_CODE = 1;
	private static final int CAPTURE_VIDEO_REQUEST_CODE = 2;

    File mPhotoFile;
    Uri mPhotoFileUri;
    File mVideoFile;
    Uri mVideoFileUri;
    String mDisplayFolder;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
    	super.onCreate(savedInstanceState);
    	setContentView(R.layout.activity_main);
    	Button takePhotoButton = (Button) findViewById(R.id.photoIntentButton);
    	takePhotoButton.setOnClickListener(new OnClickListener() {
    		public void onClick(View v) {
    			Intent intent = new Intent(MediaStore.ACTION_IMAGE_CAPTURE);
    			File mediaStorageDir = new File(Environment.getExternalStoragePublicDirectory(
    					Environment.DIRECTORY_PICTURES), "Hour20");
    			 if (! mediaStorageDir.exists()){
    				   mediaStorageDir.mkdirs();
    			 }
    			String timeStamp = new SimpleDateFormat("yyyyMMdd_HHmmss").format(new Date());
    			mDisplayFolder = "Pictures" + File.separator +"Hour20" + File.separator +"IMG_"+ timeStamp + ".jpg";
    			mPhotoFile = new File(mediaStorageDir.getPath() + File.separator +"IMG_"+ timeStamp + ".jpg");
    			mPhotoFileUri=Uri.fromFile(mPhotoFile);
    			intent.putExtra(MediaStore.EXTRA_OUTPUT,mPhotoFileUri ); 
    			startActivityForResult(intent, CAPTURE_IMAGE_REQUEST_CODE);
    		}
    	});
    	Button shootVideoButton = (Button) findViewById(R.id.videoIntentButton);
    	shootVideoButton.setOnClickListener(new OnClickListener() {
    		public void onClick(View v) {
    			Intent intent = new Intent(MediaStore.ACTION_VIDEO_CAPTURE);
    			File mediaStorageDir = new File(Environment.getExternalStoragePublicDirectory(
    					Environment.DIRECTORY_PICTURES), "Hour20");
    			if (! mediaStorageDir.exists()){
 				   mediaStorageDir.mkdirs();
 			    }
    			String timeStamp = new SimpleDateFormat("yyyyMMdd_HHmmss").format(new Date());
    			mDisplayFolder = "Pictures" + File.separator +"Hour20" + File.separator +"VID_"+ timeStamp + ".mp4";
    			mVideoFile = new File(mediaStorageDir.getPath() + File.separator +"VID_"+ timeStamp + ".mp4");
    			mVideoFileUri=Uri.fromFile(mVideoFile);
    			intent.putExtra(MediaStore.EXTRA_OUTPUT, mVideoFileUri); 
    			startActivityForResult(intent, CAPTURE_VIDEO_REQUEST_CODE);
    		}
    	});
    	Button customCameraButton = (Button) findViewById(R.id.customCameraButton);
    	customCameraButton.setOnClickListener(new OnClickListener() {
    		public void onClick(View v) {
  
            	Intent intent = new Intent(MainActivity.this, CustomCameraActivity.class);
            	startActivity(intent);  
    		}
    	});
    	
    	Button customVideoButton = (Button) findViewById(R.id.customVideoButton);
    	customVideoButton.setOnClickListener(new OnClickListener() {
    		public void onClick(View v) {
  
            	Intent intent = new Intent(MainActivity.this, CustomVideoActivity.class);
            	startActivity(intent);  
    		}
    	});
    	
    	
    	
    }

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
	    if (requestCode == CAPTURE_IMAGE_REQUEST_CODE) {
	        if (resultCode == RESULT_OK) {
	                Toast.makeText(this, "Image saved to:\n" +
	                		mDisplayFolder, Toast.LENGTH_LONG).show();	
	                Intent mediaScanIntent = new Intent(Intent.ACTION_MEDIA_SCANNER_SCAN_FILE);
	                mediaScanIntent.setData(mPhotoFileUri);
	                this.sendBroadcast(mediaScanIntent);
	        } else if (resultCode == RESULT_CANCELED) {
	        } else {
	        	Toast.makeText(this, "Something went wrong", Toast.LENGTH_LONG).show();
	        }
	    }

	    if (requestCode == CAPTURE_VIDEO_REQUEST_CODE) {
	        if (resultCode == RESULT_OK) {
	            Toast.makeText(this, "Video saved to:\n" +
	            		mDisplayFolder, Toast.LENGTH_LONG).show();
	            Intent mediaScanIntent = new Intent(Intent.ACTION_MEDIA_SCANNER_SCAN_FILE);
                mediaScanIntent.setData(mVideoFileUri);
                this.sendBroadcast(mediaScanIntent);
	        } else if (resultCode == RESULT_CANCELED) {
	        } else {
	        	Toast.makeText(this, "Something went wrong", Toast.LENGTH_LONG).show();	        }
	    }
	}

}
