package com.bffmedia.hour22;


import java.io.File;
import java.io.FileNotFoundException;
import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

import android.app.AlertDialog;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.Toast;

import com.facebook.Request;
import com.facebook.Response;
import com.facebook.Session;
import com.facebook.SessionState;
import com.facebook.UiLifecycleHelper;
import com.facebook.widget.LoginButton;

public class MainFragment extends Fragment {

	private UiLifecycleHelper uiHelper;
	private Button photoButton;

	File mPhotoFile;
	Uri mPhotoFileUri;
	File mVideoFile;
	Uri mVideoFileUri;
	String mDisplayFolder;
	private static final int CAPTURE_IMAGE_REQUEST_CODE = 1;
	private static final List<String> PERMISSIONS = Arrays.asList("publish_actions");


	private Session.StatusCallback callback = new Session.StatusCallback() {
		@Override
		public void call(Session session, SessionState state, Exception exception) {
			if (exception!=null){
				Log.d("StatusCallback", exception.getMessage());
			}
			onSessionStateChange(session, state, exception);
		}
	};

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		uiHelper = new UiLifecycleHelper(getActivity(), callback);
		uiHelper.onCreate(savedInstanceState);
	}

	@Override
	public View onCreateView(LayoutInflater inflater, 
			ViewGroup container, 
			Bundle savedInstanceState) {
		View view = inflater.inflate(R.layout.fragment_facebook, container, false);
		LoginButton authButton = (LoginButton) view.findViewById(R.id.authButton);
		authButton.setFragment(this);


		photoButton = (Button) view.findViewById(R.id.photoButton);
		photoButton.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				Session session = Session.getActiveSession();
				if (session != null) {
					if (hasPublishPermission()) {
						// We can do the action right away.
						Intent intent = new Intent(MediaStore.ACTION_IMAGE_CAPTURE);
						File mediaStorageDir = new File(Environment.getExternalStoragePublicDirectory(
								Environment.DIRECTORY_PICTURES), "Hour20");
						if (! mediaStorageDir.exists()){
							mediaStorageDir.mkdirs();
						}
						String timeStamp = new SimpleDateFormat("yyyyMMdd_HHmmss").format(new Date());
						mDisplayFolder = "Pictures" + File.separator +"Hour22" + File.separator +"IMG_"+ timeStamp + ".jpg";
						mPhotoFile = new File(mediaStorageDir.getPath() + File.separator +"IMG_"+ timeStamp + ".jpg");
						mPhotoFileUri=Uri.fromFile(mPhotoFile);
						intent.putExtra(MediaStore.EXTRA_OUTPUT,mPhotoFileUri ); 
						startActivityForResult(intent, CAPTURE_IMAGE_REQUEST_CODE);
					} else {
						// We need to get new permissions, then complete the action when we get called back.
						session.requestNewPublishPermissions(new Session.NewPermissionsRequest(MainFragment.this, PERMISSIONS));
					}
				}




			}
		});


		return view;
	}

	private void onSessionStateChange(Session session, SessionState state, Exception exception) {
		Log.i("SessionStateChange", "SessionState " +state);
		if (state.isOpened()) {
			photoButton.setVisibility(View.VISIBLE);
		} else if (state.isClosed()) {
			photoButton.setVisibility(View.INVISIBLE);
		} else if (state == SessionState.OPENED_TOKEN_UPDATED) {
			photoButton.setVisibility(View.VISIBLE);
		}
	}


	private void postPhoto(File photoFile) {
		Request request;
		try {
			request = Request.newUploadPhotoRequest(Session.getActiveSession(), photoFile, new Request.Callback(){
				@Override
				public void onCompleted(Response response) {
					String resultMessage = null;
					if (response.getError()!=null) {
						resultMessage = response.getError().getErrorMessage();
					} else {
						resultMessage = "Successfully posted photo";
					}
					new AlertDialog.Builder(getActivity()).setMessage(resultMessage).show();
				}
			});
			request.executeAsync();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		}
	}


	@Override
	public void onResume() {
		super.onResume();
		Session session = Session.getActiveSession();
		if (session != null &&
				(session.isOpened() || session.isClosed()) ) {
			onSessionStateChange(session, session.getState(), null);
		}
		uiHelper.onResume();
	}

	private boolean hasPublishPermission() {
		Session session = Session.getActiveSession();
		return session != null && session.getPermissions().contains("publish_actions");
	}

	@Override
	public void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		uiHelper.onActivityResult(requestCode, resultCode, data);
		if (requestCode == CAPTURE_IMAGE_REQUEST_CODE) {
			if (resultCode ==FragmentActivity.RESULT_OK) {
				Toast.makeText(getActivity(), "Image saved to:\n" +
						mDisplayFolder, Toast.LENGTH_LONG).show();	
				Intent mediaScanIntent = new Intent(Intent.ACTION_MEDIA_SCANNER_SCAN_FILE);
				mediaScanIntent.setData(mPhotoFileUri);
				getActivity().sendBroadcast(mediaScanIntent);
				postPhoto(mPhotoFile);
			} else if (resultCode == FragmentActivity.RESULT_CANCELED) {
			} else {
				Toast.makeText(getActivity(), "Something went wrong", Toast.LENGTH_LONG).show();
			}
		}
	}

	@Override
	public void onPause() {
		super.onPause();
		uiHelper.onPause();
	}

	@Override
	public void onDestroy() {
		super.onDestroy();
		uiHelper.onDestroy();
	}

	@Override
	public void onSaveInstanceState(Bundle outState) {
		super.onSaveInstanceState(outState);
		uiHelper.onSaveInstanceState(outState);
	}

}

